@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Access to the AcousticBrainz API
 
-our $VERSION = '0.0401';
+our $VERSION = '0.0500';
 
 use Moo;
 use strictures 2;
@@ -19,7 +19,7 @@ use Try::Tiny;
 
 has base => (
     is      => 'rw',
-    default => sub { Mojo::URL->new('https://acousticbrainz.org/api/v1') },
+    default => sub { 'https://acousticbrainz.org/api/v1' },
 );
 
 
@@ -32,17 +32,13 @@ has ua => (
 sub fetch {
     my ( $self, %args ) = @_;
 
-    my $query;
-    if ( $args{query} ) {
-        $query = join '&', map { "$_=$args{query}->{$_}" } keys %{ $args{query} };
-    }
-
     croak 'No mbid provided' unless $args{mbid};
     croak 'No endpoint provided' unless $args{endpoint};
+    croak 'No query provided' unless $args{query};
 
-    my $url = $self->base . '/'. $args{mbid} . '/'. $args{endpoint};
-    $url .= '?' . $query
-        if $query;
+    my $url = Mojo::URL->new($self->base)
+        ->path($args{mbid} . '/'. $args{endpoint})
+        ->query(%{ $args{query} });
 
     my $tx = $self->ua->get($url);
 
@@ -61,11 +57,11 @@ sub _handle_response {
     if ( $res->is_success ) {
         my $body = $res->body;
         try {
-            $data = decode_json( $res->body );
+            $data = decode_json($body);
         }
         catch {
             croak $body, "\n";
-        }
+        };
     }
     else {
         croak "Connection error: ", $res->message;
@@ -88,7 +84,7 @@ WebService::AcousticBrainz - Access to the AcousticBrainz API
 
 =head1 VERSION
 
-version 0.0401
+version 0.0500
 
 =head1 SYNOPSIS
 
@@ -149,7 +145,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Gene Boggs.
+This software is copyright (c) 2021 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
